﻿using System;

namespace Niche.Common
{
    /// <summary>
    /// Cribbed from Oren Eini (ayende.com), provides an action to execute at the end of a block. 
    /// </summary>
    /// See http://www.ayende.com/Blog/archive/8065.aspx for details.
    public class DisposableAction : IDisposable
    {
        /// <summary>
        /// Initializes a new instance of the DisposableAction class.
        /// </summary>
        /// <param name="action">Action to invoke when disposed</param>
        public DisposableAction(Action action)
        {
            if (action == null)
            {
                throw new ArgumentNullException("action");
            }

            mAction = action;
        }

        /// <summary>
        /// Fire the contained action.
        /// </summary>
        public void Dispose()
        {
            mAction();
        }

        /// <summary>
        /// The action to invoke at the end of the block.
        /// </summary>
        private readonly Action mAction;
    }
}